from leapp import reporting
from leapp.actors import Actor
from leapp.libraries.common import rpms
from leapp.models import InstalledRPM
from leapp.tags import FactsPhaseTag, IPUWorkflowTag
from leapp.reporting import Report

class EBSInhibit(Actor):
    """
    Checks for problematic EBS Server rpm that will cause a dependency related failure on upgrade.
    """

    name = 'EBSinhibit'
    consumes = ()
    produces = (Report,)
    tags = (IPUWorkflowTag, FactsPhaseTag)

    def process(self):
        output = rpms.get_installed_rpms()

        result = InstalledRPM()
        issuePackages = ["oracle-ebs-server-R12-preinstall"]
        issueList = []
        for entry in output:
            entry = entry.strip()
            if not entry:
                continue
            name, version, release, epoch, packager, arch, pgpsig = entry.split('|')
            for item in issuePackages:
                if item in name:
                    issueList.append(name)
        if issueList:
            issueList = str(issueList).strip("[]")
            issueList = issueList.replace("'","")
            warnMsg = 'Oracle-EBS-server-R12-preinstall is not available on Oracle Linux 9. If you want to proceed with in-place upgrade, please remove package oracle-ebs-server-R12-preinstall and rerun in-place upgrade.'
            self.log.warning(warnMsg)
            reporting.create_report(
                [
                    reporting.Title("Detected installed package oracle-ebs-server-R12-preinstall."),
                    reporting.Summary(warnMsg),
                    reporting.Severity(reporting.Severity.HIGH),
                    reporting.Groups([reporting.Groups.REPOSITORY]),
                    reporting.Groups([reporting.Groups.INHIBITOR]),
                    reporting.Remediation(
                        hint=(
                            "Please run command #dnf remove for all conflicting packages before upgrade, e.g. #dnf remove " + issueList.replace(",","")
                        )
                    ),
                ]
            )

